==> cscec5b-dataexchange-api-3.0.1-20211009.103740-1-sources.jar: com/ejianc/business/dataexchange/vo/CmContractInfoVO.java <==
package com.ejianc.business.dataexchange.vo;


/**
 * 合同Info vo
 * @author sunq
 * @since 2020-11-08 08:02:02
 */
public class CmContractInfoVO {

    private static final long serialVersionUID = 1L;

    private String pkContractinfo;
    private String pkContract;
    private String infocode;
    private String infoname;
    private String name;

    private String infounit;
    private String infoamount;
    private double infoprice;

    public String getPkContractinfo() {
        return pkContractinfo;
    }

    public void setPkContractinfo(String pkContractinfo) {
        this.pkContractinfo = pkContractinfo;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public String getInfocode() {
        return infocode;
    }

    public void setInfocode(String infocode) {
        this.infocode = infocode;
    }

    public String getInfoname() {
        return infoname;
    }

    public void setInfoname(String infoname) {
        this.infoname = infoname;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getInfounit() {
        return infounit;
    }

    public void setInfounit(String infounit) {
        this.infounit = infounit;
    }

    public String getInfoamount() {
        return infoamount;
    }

    public void setInfoamount(String infoamount) {
        this.infoamount = infoamount;
    }

    public double getInfoprice() {
        return infoprice;
    }

    public void setInfoprice(double infoprice) {
        this.infoprice = infoprice;
    }
}

==> cscec5b-dataexchange-api-3.0.1-20220212.123129-19-sources.jar: com/ejianc/business/dataexchange/vo/CmContractInfoVO.java <==
package com.ejianc.business.dataexchange.vo;


/**
 * 合同Info vo
 * @author sunq
 * @since 2020-11-08 08:02:02
 */
public class CmContractInfoVO {

    private static final long serialVersionUID = 1L;

    private String pkContractinfo;
    private String pkContract;
    private String infocode;
    private String infoname;
    private String name;

    private String infounit;
    private String infoamount;
    private double infoprice;
    private double infoSumNum;

    public String getPkContractinfo() {
        return pkContractinfo;
    }

    public void setPkContractinfo(String pkContractinfo) {
        this.pkContractinfo = pkContractinfo;
    }

    public String getPkContract() {
        return pkContract;
    }

    public void setPkContract(String pkContract) {
        this.pkContract = pkContract;
    }

    public String getInfocode() {
        return infocode;
    }

    public void setInfocode(String infocode) {
        this.infocode = infocode;
    }

    public String getInfoname() {
        return infoname;
    }

    public void setInfoname(String infoname) {
        this.infoname = infoname;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public String getInfounit() {
        return infounit;
    }

    public void setInfounit(String infounit) {
        this.infounit = infounit;
    }

    public String getInfoamount() {
        return infoamount;
    }

    public void setInfoamount(String infoamount) {
        this.infoamount = infoamount;
    }

    public double getInfoprice() {
        return infoprice;
    }

    public void setInfoprice(double infoprice) {
        this.infoprice = infoprice;
    }

    public double getInfoSumNum() {
        return infoSumNum;
    }

    public void setInfoSumNum(double infoSumNum) {
        this.infoSumNum = infoSumNum;
    }
}
